@@ -149,7 +149,7 @@ class Command(metaclass(ABCMeta)):
         '''
         if cls is Command:
             if cmd is not None:
-                from xoutil.six import string_types as text
+                from six import string_types as text
                 name = cmd if isinstance(cmd, text) else command_name(cmd)
             else:
                 raise ValueError('missing command specification!')
